// global constants from aviary browser.js
const NS_ERROR_MODULE_NETWORK = 2152398848;
const NS_NET_STATUS_READ_FROM = NS_ERROR_MODULE_NETWORK + 8;
const NS_NET_STATUS_WROTE_TO  = NS_ERROR_MODULE_NETWORK + 9;

//@line 38 "/cygdrive/c/builds/tinderbox/Fx-Trunk/WINNT_5.2_Depend/mozilla/browser/base/content/web-panels.js"

var panelProgressListener = {
    onProgressChange : function (aWebProgress, aRequest,
                                    aCurSelfProgress, aMaxSelfProgress,
                                    aCurTotalProgress, aMaxTotalProgress) {
    },
    
    onStateChange : function(aWebProgress, aRequest, aStateFlags, aStatus)
    {
        if (!aRequest)
          return;

        //ignore local/resource:/chrome: files
        if (aStatus == NS_NET_STATUS_READ_FROM || aStatus == NS_NET_STATUS_WROTE_TO)
           return;

        const nsIWebProgressListener = Components.interfaces.nsIWebProgressListener;
        const nsIChannel = Components.interfaces.nsIChannel;
        if (aStateFlags & nsIWebProgressListener.STATE_START && 
            aStateFlags & nsIWebProgressListener.STATE_IS_NETWORK) {
            window.parent.document.getElementById('sidebar-throbber').setAttribute("loading", "true");
        }
        else if (aStateFlags & nsIWebProgressListener.STATE_STOP &&
                aStateFlags & nsIWebProgressListener.STATE_IS_NETWORK) {
            window.parent.document.getElementById('sidebar-throbber').removeAttribute("loading");
        }
    }
    ,

    onLocationChange : function(aWebProgress, aRequest, aLocation) {
    },

    onStatusChange : function(aWebProgress, aRequest, aStatus, aMessage) {
    },

    onSecurityChange : function(aWebProgress, aRequest, aState) { 
    },

    QueryInterface : function(aIID)
    {
        if (aIID.equals(Components.interfaces.nsIWebProgressListener) ||
            aIID.equals(Components.interfaces.nsISupportsWeakReference) ||
            aIID.equals(Components.interfaces.nsISupports))
        return this;
        throw Components.results.NS_NOINTERFACE;
    }
};

var gLoadFired = false;
function loadWebPanel(aURI) {
    var panelBrowser = document.getElementById('web-panels-browser');
    if (gLoadFired)
        panelBrowser.webNavigation.loadURI(aURI, nsIWebNavigation.LOAD_FLAGS_NONE, null, null, null);
    panelBrowser.setAttribute("cachedurl", aURI);
}

function load()
{
  var panelBrowser = document.getElementById('web-panels-browser');
  panelBrowser.webProgress.addProgressListener(panelProgressListener, Components.interfaces.nsIWebProgress.NOTIFY_ALL);
  if (panelBrowser.getAttribute("cachedurl"))
    panelBrowser.webNavigation.loadURI(panelBrowser.getAttribute("cachedurl"), nsIWebNavigation.LOAD_FLAGS_NONE, null, null, null);
  gNavigatorBundle = document.getElementById("bundle_browser");
    
  gLoadFired = true;

  // xSidebar - bookmark support for web-panels
  initServices();
  initBMService();
  BMSVC.readBookmarks();  
}

function unload()
{
  var panelBrowser = document.getElementById('web-panels-browser');
  panelBrowser.webProgress.removeProgressListener(panelProgressListener);
}

/// xSidebar mods

var xsbWebPanel = {

  // Content area tooltip for web-panel
  FillInHTMLTooltip : function (tipElement) {
    if (tipElement.namespaceURI == "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul")
      return retVal;

    const XLinkNS = "http://www.w3.org/1999/xlink";

    this.row = [document.getElementById('ah1row'), document.getElementById('ah2row')];
    this.row[0].hidden = this.row[1].hidden = true;
    this.row[0].value = this.row[1].value = "";
    this.row[0].altText = "";
    this.row[0].xTitle = "";
    this.node = document.tooltipNode;
    this.show = false;

    for (this.node; this.node; this.node = this.node.parentNode) {
    // go up the tree until both rows are filled or end of tree
      if (!this.row[1].value) {
      // if mouse is over a link fill row1 with href
        if (this.node instanceof Components.interfaces.nsIDOMHTMLAnchorElement ||
            this.node instanceof Components.interfaces.nsIDOMHTMLAreaElement)
          this.row[1].value = this.node.href;
      }
      if (!this.row[0].value) {
        try {
          if (("hasAttribute" in this.node) && this.node.hasAttribute('alt'))
          // if mouse is over an element (or link)
          // with a alt-attribute fill altText with alt
            this.row[0].altText = this.node.getAttribute("alt");
          if (("hasAttribute" in this.node) && this.node.hasAttribute('title'))
          // if mouse is over an element (or link)
          // with a title fill row0 with title
            this.row[0].value = this.node.getAttribute("title");
          if (("hasAttributeNS" in this.node) && this.node.hasAttributeNS(XLinkNS, 'title'))
          // if mouse is over an element (or link)
          // with an xLink fill xTitle with title
            this.row[0].xTitle = this.node.getAttributeNS(XLinkNS, "title");
        } catch (e) {}
      }
      // if both rows have content stop the loop
      if (this.row[0].value && this.row[1].value)
        break;
    }
    // check for alt. If there is no title fill in alt
    if (!this.row[0].value)
      this.row[0].value = this.row[0].xTitle ? this.row[0].xTitle : this.row[0].altText;
    // check if one or both rows have text
    for (var x = 0; x < this.row.length; x++) {
      if (this.row[x].value) {
        this.row[x].hidden = false
        this.show=true
      }
    }
    return this.show;
  },

  // Replacement for nsContextMenu function addBookmark
  addBookmark : function () {
    var docshell = document.getElementById( "web-panels-browser" ).webNavigation;
    BookmarksUtils.addBookmark( docshell.currentURI.spec,
                                docshell.document.title,
                                docshell.document.characterSet,
                                false );
  },

  contextMenuInit : function () {
    var cm = document.getElementById("contentAreaContextMenu");
    if (cm)
      cm.addEventListener("popupshowing",xsbWebPanel.contextMenu,false);
  },

  contextMenu : function () {
    var cm = gContextMenu;
    if (cm) {
      cm.addBookmark = function addBookmark() {
        xsbWebPanel.addBookmark();
      }
    }
  }
}

function getBrowser()
{
  return top.document.getElementById("content");
}

// spin off from <https://bugzilla.mozilla.org/show_bug.cgi?id=321981>
// Neil says to cache a copy of the preference service which already has
// the nsIPrefBranch interface, you declare a global e.g.:

if (!gPref) {
  var gPref = Components.classes["@mozilla.org/preferences-service;1"]
                        .getService(Components.interfaces.nsIPrefBranch)
                        .QueryInterface(Components.interfaces.nsIPrefBranch);
}

window.addEventListener("load", xsbWebPanel.contextMenuInit, true);
